import { RenderRequestedEventArgs as RenderRequestedEventArgs_internal } from "./RenderRequestedEventArgs";
import { ensureBool } from "igniteui-react-core/ES5/componentUtil";
/**
 * EventArgs class for RenderRequested events.
*
* Use the `RenderRequested` class for RenderRequested events.
*
* ```ts
* <IgrDataChart
* 		dataSource={this.data}
* 		ref={this.onChartRef}
* 		width="100%"
* 		height="100%" >
* <IgrCategoryXAxis name="xAxis" label="Country" />
* <IgrNumericYAxis name="yAxis" minimumValue={0} />
* <IgrColumnSeries name="series1"
* 		xAxisName="xAxis"
* 		yAxisName="yAxis"
* 		valueMemberPath="Coal"
* 		renderRequested= {this.OnRenderRequested}/>
*  </IgrDataChart>
* ```
*
* ```ts
* let series1 = new IgrColumnSeries({ name: "series1" });
* series1.valueMemberPath = "USA";
* series1.title = "USA";
* series1.xAxisName = "xAxis";
* series1.yAxisName = "yAxis";
* series1.renderRequested = this.OnRenderRequested;
*
* public OnRenderRequested =( s:IgrSeries, e:RenderRequestedEventArgs) => {
*
*   }
* ```
*/
var RenderRequestedEventArgs = /** @class */ (function () {
    function RenderRequestedEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    RenderRequestedEventArgs.prototype.createImplementation = function () {
        return new RenderRequestedEventArgs_internal();
    };
    Object.defineProperty(RenderRequestedEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    RenderRequestedEventArgs.prototype.onImplementationCreated = function () {
    };
    RenderRequestedEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(RenderRequestedEventArgs.prototype, "animate", {
        /**
         * True if animation is requested.
        *
        * Use the `animate` property true if the animation is requested.
        *
        * ```ts
        * e.animation = true;
        * ```
        */
        get: function () {
            return this.i.animate;
        },
        set: function (v) {
            this.i.animate = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    return RenderRequestedEventArgs;
}());
export { RenderRequestedEventArgs };
